{% extends "base.html" %}
{% load i18n %}

{% block content %}
<h1 class="heading heading--profiles">{% trans "Login Success" %}</h1>
<div class="profiles">
    <h4 class="heading heading--feeback-title">{% trans "Welcome Back!" %}</h4>
    <a href="/">{% trans "Home Page" %}</a>
  </div>
{% endblock %}
